searchNodes=[{"type":"module","title":"Money","doc":"Defines a Money struct along with convenience methods for working with currencies. Examples iex&gt; money = Money . new ( 500 , :USD ) % Money { amount : 500 , currency : :USD } iex&gt; money = Money . add ( money , 550 ) % Money { amount : 1050 , currency : :USD } iex&gt; Money . to_string ( money ) &quot;$10.50&quot; Configuration You can set defaults in your Mix configuration to make working with Money a little easier. config :money , default_currency : :EUR , # this allows you to do Money.new(100) separator : &quot;.&quot; , # change the default thousands separator for Money.to_string delimiter : &quot;,&quot; , # change the default decimal delimiter for Money.to_string symbol : false , # don’t display the currency symbol in Money.to_string symbol_on_right : false , # position the symbol symbol_space : false , # add a space between symbol and number fractional_unit : true , # display units after the delimiter strip_insignificant_zeros : false , # don’t display the insignificant zeros or the delimiter code : false , # add the currency code after the number minus_sign_first : true , # display the minus sign before the currency symbol for Money.to_string strip_insignificant_fractional_unit : false # don&#39;t display the delimiter or fractional units if the fractional units are only insignificant zeros","ref":"Money.html"},{"type":"function","title":"Money.abs/1","doc":"Returns a Money with the arithmetical absolute of the amount. Examples iex&gt; Money . new ( - 100 , :USD ) |&gt; Money . abs % Money { amount : 100 , currency : :USD } iex&gt; Money . new ( 100 , :USD ) |&gt; Money . abs % Money { amount : 100 , currency : :USD }","ref":"Money.html#abs/1"},{"type":"function","title":"Money.add/2","doc":"Adds two Money together or an integer (cents) amount to a Money Examples iex&gt; Money . add ( Money . new ( 100 , :USD ) , Money . new ( 50 , :USD ) ) % Money { amount : 150 , currency : :USD } iex&gt; Money . add ( Money . new ( 100 , :USD ) , 50 ) % Money { amount : 150 , currency : :USD } iex&gt; Money . add ( Money . new ( 100 , :USD ) , 5.55 ) % Money { amount : 655 , currency : :USD }","ref":"Money.html#add/2"},{"type":"function","title":"Money.cmp/2","doc":"Compares two Money structs with each other. They must each be of the same currency and then their amounts are compared. If the first amount is larger than the second :gt is returned, if less than :lt is returned, if both amounts are equal :eq is returned. See compare/2 for a similar function that returns -1 , 0 or 1 instead. Examples iex&gt; Money . cmp ( Money . new ( 100 , :USD ) , Money . new ( 100 , :USD ) ) :eq iex&gt; Money . cmp ( Money . new ( 100 , :USD ) , Money . new ( 101 , :USD ) ) :lt iex&gt; Money . cmp ( Money . new ( 101 , :USD ) , Money . new ( 100 , :USD ) ) :gt","ref":"Money.html#cmp/2"},{"type":"function","title":"Money.compare/2","doc":"Compares two Money structs with each other. They must each be of the same currency and then their amounts are compared. If the first amount is larger than the second 1 is returned, if less than -1 is returned, if both amounts are equal 0 is returned. See cmp/2 for a similar function that returns :lt , :eq or :gt instead. Examples iex&gt; Money . compare ( Money . new ( 100 , :USD ) , Money . new ( 100 , :USD ) ) 0 iex&gt; Money . compare ( Money . new ( 100 , :USD ) , Money . new ( 101 , :USD ) ) - 1 iex&gt; Money . compare ( Money . new ( 101 , :USD ) , Money . new ( 100 , :USD ) ) 1","ref":"Money.html#compare/2"},{"type":"function","title":"Money.divide/2","doc":"Divides up Money by an amount Examples iex&gt; Money . divide ( Money . new ( 100 , :USD ) , 2 ) [ % Money { amount : 50 , currency : :USD } , % Money { amount : 50 , currency : :USD } ] iex&gt; Money . divide ( Money . new ( 101 , :USD ) , 2 ) [ % Money { amount : 51 , currency : :USD } , % Money { amount : 50 , currency : :USD } ]","ref":"Money.html#divide/2"},{"type":"function","title":"Money.equals?/2","doc":"Returns true if two Money of the same currency have the same amount Examples iex&gt; Money . equals? ( Money . new ( 100 , :USD ) , Money . new ( 100 , :USD ) ) true iex&gt; Money . equals? ( Money . new ( 101 , :USD ) , Money . new ( 100 , :USD ) ) false iex&gt; Money . equals? ( Money . new ( 100 , :USD ) , Money . new ( 100 , :CAD ) ) false","ref":"Money.html#equals?/2"},{"type":"function","title":"Money.multiply/2","doc":"Multiplies a Money by an amount Examples iex&gt; Money . multiply ( Money . new ( 100 , :USD ) , 10 ) % Money { amount : 1000 , currency : :USD } iex&gt; Money . multiply ( Money . new ( 100 , :USD ) , 1.5 ) % Money { amount : 150 , currency : :USD }","ref":"Money.html#multiply/2"},{"type":"function","title":"Money.neg/1","doc":"Returns a Money with the amount negated. Examples iex&gt; Money . new ( 100 , :USD ) |&gt; Money . neg % Money { amount : - 100 , currency : :USD } iex&gt; Money . new ( - 100 , :USD ) |&gt; Money . neg % Money { amount : 100 , currency : :USD }","ref":"Money.html#neg/1"},{"type":"function","title":"Money.negative?/1","doc":"Returns true if the amount of a Money is less than zero Examples iex&gt; Money . negative? ( Money . new ( 0 , :USD ) ) false iex&gt; Money . negative? ( Money . new ( 1 , :USD ) ) false iex&gt; Money . negative? ( Money . new ( - 1 , :USD ) ) true","ref":"Money.html#negative?/1"},{"type":"function","title":"Money.new/1","doc":"Create a new Money struct using a default currency. The default currency can be set in the system Mix config. Config config :money , default_currency : :USD Examples Money . new ( 123 ) % Money { amount : 123 , currency : :USD }","ref":"Money.html#new/1"},{"type":"function","title":"Money.new/2","doc":"Create a new Money struct from currency sub-units (cents) Examples iex&gt; Money . new ( 1_000_00 , :USD ) % Money { amount : 1_000_00 , currency : :USD }","ref":"Money.html#new/2"},{"type":"function","title":"Money.parse/3","doc":"Parse a value into a Money type. The following options are available: :separator - default &quot;,&quot; , sets the separator for groups of thousands. &quot;1,000&quot; :delimiter - default &quot;.&quot; , sets the decimal delimiter. &quot;1.23&quot; Examples iex&gt; Money . parse ( &quot;$1,234.56&quot; , :USD ) { :ok , % Money { amount : 123456 , currency : :USD } } iex&gt; Money . parse ( &quot;1.234,56&quot; , :EUR , separator : &quot;.&quot; , delimiter : &quot;,&quot; ) { :ok , % Money { amount : 123456 , currency : :EUR } } iex&gt; Money . parse ( &quot;1.234,56&quot; , :WRONG ) :error iex&gt; Money . parse ( 1_234.56 , :USD ) { :ok , % Money { amount : 123456 , currency : :USD } } iex&gt; Money . parse ( 1_234 , :USD ) { :ok , % Money { amount : 123400 , currency : :USD } } iex&gt; Money . parse ( - 1_234.56 , :USD ) { :ok , % Money { amount : - 123456 , currency : :USD } } iex&gt; Money . parse ( Decimal . from_float ( 1_234.56 ) , :USD ) { :ok , % Money { amount : 123456 , currency : :USD } }","ref":"Money.html#parse/3"},{"type":"function","title":"Money.parse!/3","doc":"Parse a value into a Money type. Similar to parse/3 but returns a %Money{} or raises an error if parsing fails. Examples iex&gt; Money . parse! ( &quot;1,234.56&quot; , :USD ) % Money { amount : 123456 , currency : :USD } iex&gt; Money . parse! ( &quot;wrong&quot; , :USD ) ** (ArgumentError) unable to parse &quot;wrong&quot; with currency :USD","ref":"Money.html#parse!/3"},{"type":"function","title":"Money.positive?/1","doc":"Returns true if the amount of a Money is greater than zero Examples iex&gt; Money . positive? ( Money . new ( 0 , :USD ) ) false iex&gt; Money . positive? ( Money . new ( 1 , :USD ) ) true iex&gt; Money . positive? ( Money . new ( - 1 , :USD ) ) false","ref":"Money.html#positive?/1"},{"type":"function","title":"Money.round/2","doc":"Rounds a Money struct using a given number of places. round respects the rounding mode within the current Decimal context. By default round rounds to zero decimal places, using the currency's exponent. This results in rounding to whole values of the currency. Currencies without an exponent are not rounded unless a different value is passed for places other than the default. Examples iex&gt; Money . round ( Money . new ( 123456 , :GBP ) ) % Money { amount : 123500 , currency : :GBP } iex&gt; Money . round ( Money . new ( - 123420 , :EUR ) ) % Money { amount : - 123400 , currency : :EUR } iex&gt; Money . round ( Money . new ( - 123420 , :EUR ) , - 3 ) % Money { amount : - 100000 , currency : :EUR } # Round to tenth of exponent iex&gt; Money . round ( Money . new ( 123425 , :EUR ) , 1 ) % Money { amount : 123430 , currency : :EUR } # Currencies round based on their exponent iex&gt; Money . round ( Money . new ( 820412 , :JPY ) ) % Money { amount : 820412 , currency : :JPY } iex&gt; Money . round ( Money . new ( 820412 , :JPY ) , - 3 ) % Money { amount : 820000 , currency : :JPY }","ref":"Money.html#round/2"},{"type":"function","title":"Money.subtract/2","doc":"Subtracts one Money from another or an integer (cents) from a Money Examples iex&gt; Money . subtract ( Money . new ( 150 , :USD ) , Money . new ( 50 , :USD ) ) % Money { amount : 100 , currency : :USD } iex&gt; Money . subtract ( Money . new ( 150 , :USD ) , 50 ) % Money { amount : 100 , currency : :USD } iex&gt; Money . subtract ( Money . new ( 150 , :USD ) , 1.25 ) % Money { amount : 25 , currency : :USD }","ref":"Money.html#subtract/2"},{"type":"function","title":"Money.to_decimal/1","doc":"Converts a Money struct to a Decimal representation Examples iex&gt; Money . to_decimal ( Money . new ( 123456 , :GBP ) ) # Decimal &lt; 1234.56 &gt; iex&gt; Money . to_decimal ( Money . new ( - 123420 , :EUR ) ) # Decimal &lt; - 1234.20 &gt;","ref":"Money.html#to_decimal/1"},{"type":"function","title":"Money.to_string/2","doc":"Converts a Money struct to a string representation The following options are available: :separator - default &quot;,&quot; , sets the separator for groups of thousands. &quot;1,000&quot; :delimiter - default &quot;.&quot; , sets the decimal delimiter. &quot;1.23&quot; :symbol - default true , sets whether to display the currency symbol or not. :symbol_on_right - default false , display the currency symbol on the right of the number, eg: 123.45€ :symbol_space - default false , add a space between currency symbol and number, eg: € 123,45 or 123.45 € :fractional_unit - default true , show the remaining units after the delimiter :strip_insignificant_zeros - default false , strip zeros after the delimiter :code - default false , append the currency code after the number :minus_sign_first - default true , display the minus sign before the currency symbol for negative values :strip_insignificant_fractional_unit - default false , don't display the delimiter or fractional units if the fractional units are only insignificant zeros Examples iex&gt; Money . to_string ( Money . new ( 123456 , :GBP ) ) &quot;£1,234.56&quot; iex&gt; Money . to_string ( Money . new ( 123456 , :EUR ) , separator : &quot;.&quot; , delimiter : &quot;,&quot; ) &quot;€1.234,56&quot; iex&gt; Money . to_string ( Money . new ( 123456 , :EUR ) , symbol : false ) &quot;1,234.56&quot; iex&gt; Money . to_string ( Money . new ( 123456 , :EUR ) , symbol : false , separator : &quot;&quot; ) &quot;1234.56&quot; iex&gt; Money . to_string ( Money . new ( 123456 , :EUR ) , fractional_unit : false ) &quot;€1,234&quot; iex&gt; Money . to_string ( Money . new ( 123450 , :EUR ) , strip_insignificant_zeros : true ) &quot;€1,234.5&quot; iex&gt; Money . to_string ( Money . new ( 123450 , :EUR ) , code : true ) &quot;€1,234.50 EUR&quot; iex&gt; Money . to_string ( Money . new ( - 123450 , :EUR ) ) &quot;-€1,234.50&quot; iex&gt; Money . to_string ( Money . new ( - 123450 , :EUR ) , minus_sign_first : false ) &quot;€-1,234.50&quot; iex&gt; Money . to_string ( Money . new ( 123400 , :EUR ) , strip_insignificant_fractional_unit : true ) &quot;€1,234&quot; iex&gt; Money . to_string ( Money . new ( 123450 , :EUR ) , strip_insignificant_fractional_unit : true ) &quot;€1,234.50&quot; It can also be interpolated (It implements the String.Chars protocol) To control the formatting, you can use the above options in your config, more information is in the introduction to Money Examples iex&gt; &quot;Total: \#{ Money . new ( 100_00 , :USD ) } &quot; &quot;Total: $100.00&quot;","ref":"Money.html#to_string/2"},{"type":"function","title":"Money.zero?/1","doc":"Returns true if the amount of a Money struct is zero Examples iex&gt; Money . zero? ( Money . new ( 0 , :USD ) ) true iex&gt; Money . zero? ( Money . new ( 1 , :USD ) ) false","ref":"Money.html#zero?/1"},{"type":"type","title":"Money.t/0","doc":"","ref":"Money.html#t:t/0"},{"type":"module","title":"Money.Currency","doc":"Provides currency support to Money . Some useful helper methods include: get/1 get!/1 exists?/1 to_atom/1 name/1 name!/1 symbol/1 symbol!/1 all/0 A helper function exists for each currency using the lowercase three-character currency code. Examples iex&gt; Money.Currency . usd ( 100 ) % Money { amount : 100 , currency : :USD }","ref":"Money.Currency.html"},{"type":"function","title":"Money.Currency.aed/1","doc":"Convenience method to create a Money object for the UAE Dirham (AED) currency. Examples iex&gt; Money.Currency . aed ( 100 ) % Money { amount : 100 , currency : :AED }","ref":"Money.Currency.html#aed/1"},{"type":"function","title":"Money.Currency.afn/1","doc":"Convenience method to create a Money object for the Afghani (AFN) currency. Examples iex&gt; Money.Currency . afn ( 100 ) % Money { amount : 100 , currency : :AFN }","ref":"Money.Currency.html#afn/1"},{"type":"function","title":"Money.Currency.all/0","doc":"Returns all the currencies Examples iex&gt; Money.Currency . all |&gt; Map . fetch! ( :GBP ) %{ name : &quot;Pound Sterling&quot; , symbol : &quot;£&quot; , exponent : 2 , number : 826 }","ref":"Money.Currency.html#all/0"},{"type":"function","title":"Money.Currency.all/1","doc":"Convenience method to create a Money object for the Lek (ALL) currency. Examples iex&gt; Money.Currency . all ( 100 ) % Money { amount : 100 , currency : :ALL }","ref":"Money.Currency.html#all/1"},{"type":"function","title":"Money.Currency.amd/1","doc":"Convenience method to create a Money object for the Armenian Dram (AMD) currency. Examples iex&gt; Money.Currency . amd ( 100 ) % Money { amount : 100 , currency : :AMD }","ref":"Money.Currency.html#amd/1"},{"type":"function","title":"Money.Currency.ang/1","doc":"Convenience method to create a Money object for the Netherlands Antillian Guilder (ANG) currency. Examples iex&gt; Money.Currency . ang ( 100 ) % Money { amount : 100 , currency : :ANG }","ref":"Money.Currency.html#ang/1"},{"type":"function","title":"Money.Currency.aoa/1","doc":"Convenience method to create a Money object for the Kwanza (AOA) currency. Examples iex&gt; Money.Currency . aoa ( 100 ) % Money { amount : 100 , currency : :AOA }","ref":"Money.Currency.html#aoa/1"},{"type":"function","title":"Money.Currency.ars/1","doc":"Convenience method to create a Money object for the Argentine Peso (ARS) currency. Examples iex&gt; Money.Currency . ars ( 100 ) % Money { amount : 100 , currency : :ARS }","ref":"Money.Currency.html#ars/1"},{"type":"function","title":"Money.Currency.aud/1","doc":"Convenience method to create a Money object for the Australian Dollar (AUD) currency. Examples iex&gt; Money.Currency . aud ( 100 ) % Money { amount : 100 , currency : :AUD }","ref":"Money.Currency.html#aud/1"},{"type":"function","title":"Money.Currency.awg/1","doc":"Convenience method to create a Money object for the Aruban Guilder (AWG) currency. Examples iex&gt; Money.Currency . awg ( 100 ) % Money { amount : 100 , currency : :AWG }","ref":"Money.Currency.html#awg/1"},{"type":"function","title":"Money.Currency.azn/1","doc":"Convenience method to create a Money object for the Azerbaijanian Manat (AZN) currency. Examples iex&gt; Money.Currency . azn ( 100 ) % Money { amount : 100 , currency : :AZN }","ref":"Money.Currency.html#azn/1"},{"type":"function","title":"Money.Currency.bam/1","doc":"Convenience method to create a Money object for the Convertible Marks (BAM) currency. Examples iex&gt; Money.Currency . bam ( 100 ) % Money { amount : 100 , currency : :BAM }","ref":"Money.Currency.html#bam/1"},{"type":"function","title":"Money.Currency.bbd/1","doc":"Convenience method to create a Money object for the Barbados Dollar (BBD) currency. Examples iex&gt; Money.Currency . bbd ( 100 ) % Money { amount : 100 , currency : :BBD }","ref":"Money.Currency.html#bbd/1"},{"type":"function","title":"Money.Currency.bdt/1","doc":"Convenience method to create a Money object for the Taka (BDT) currency. Examples iex&gt; Money.Currency . bdt ( 100 ) % Money { amount : 100 , currency : :BDT }","ref":"Money.Currency.html#bdt/1"},{"type":"function","title":"Money.Currency.bgn/1","doc":"Convenience method to create a Money object for the Bulgarian Lev (BGN) currency. Examples iex&gt; Money.Currency . bgn ( 100 ) % Money { amount : 100 , currency : :BGN }","ref":"Money.Currency.html#bgn/1"},{"type":"function","title":"Money.Currency.bhd/1","doc":"Convenience method to create a Money object for the Bahraini Dinar (BHD) currency. Examples iex&gt; Money.Currency . bhd ( 100 ) % Money { amount : 100 , currency : :BHD }","ref":"Money.Currency.html#bhd/1"},{"type":"function","title":"Money.Currency.bif/1","doc":"Convenience method to create a Money object for the Burundi Franc (BIF) currency. Examples iex&gt; Money.Currency . bif ( 100 ) % Money { amount : 100 , currency : :BIF }","ref":"Money.Currency.html#bif/1"},{"type":"function","title":"Money.Currency.bmd/1","doc":"Convenience method to create a Money object for the Bermudian Dollar (customarily known as Bermuda Dollar) (BMD) currency. Examples iex&gt; Money.Currency . bmd ( 100 ) % Money { amount : 100 , currency : :BMD }","ref":"Money.Currency.html#bmd/1"},{"type":"function","title":"Money.Currency.bnd/1","doc":"Convenience method to create a Money object for the Brunei Dollar (BND) currency. Examples iex&gt; Money.Currency . bnd ( 100 ) % Money { amount : 100 , currency : :BND }","ref":"Money.Currency.html#bnd/1"},{"type":"function","title":"Money.Currency.bob/1","doc":"Convenience method to create a Money object for the Boliviano Mvdol (BOB) currency. Examples iex&gt; Money.Currency . bob ( 100 ) % Money { amount : 100 , currency : :BOB }","ref":"Money.Currency.html#bob/1"},{"type":"function","title":"Money.Currency.bov/1","doc":"Convenience method to create a Money object for the Boliviano Mvdol (BOV) currency. Examples iex&gt; Money.Currency . bov ( 100 ) % Money { amount : 100 , currency : :BOV }","ref":"Money.Currency.html#bov/1"},{"type":"function","title":"Money.Currency.brl/1","doc":"Convenience method to create a Money object for the Brazilian Real (BRL) currency. Examples iex&gt; Money.Currency . brl ( 100 ) % Money { amount : 100 , currency : :BRL }","ref":"Money.Currency.html#brl/1"},{"type":"function","title":"Money.Currency.bsd/1","doc":"Convenience method to create a Money object for the Bahamian Dollar (BSD) currency. Examples iex&gt; Money.Currency . bsd ( 100 ) % Money { amount : 100 , currency : :BSD }","ref":"Money.Currency.html#bsd/1"},{"type":"function","title":"Money.Currency.btn/1","doc":"Convenience method to create a Money object for the Indian Rupee Ngultrum (BTN) currency. Examples iex&gt; Money.Currency . btn ( 100 ) % Money { amount : 100 , currency : :BTN }","ref":"Money.Currency.html#btn/1"},{"type":"function","title":"Money.Currency.bwp/1","doc":"Convenience method to create a Money object for the Pula (BWP) currency. Examples iex&gt; Money.Currency . bwp ( 100 ) % Money { amount : 100 , currency : :BWP }","ref":"Money.Currency.html#bwp/1"},{"type":"function","title":"Money.Currency.byn/1","doc":"Convenience method to create a Money object for the Belarusian Ruble (BYN) currency. Examples iex&gt; Money.Currency . byn ( 100 ) % Money { amount : 100 , currency : :BYN }","ref":"Money.Currency.html#byn/1"},{"type":"function","title":"Money.Currency.byr/1","doc":"Convenience method to create a Money object for the Belarusian Ruble (BYR) currency. Examples iex&gt; Money.Currency . byr ( 100 ) % Money { amount : 100 , currency : :BYR }","ref":"Money.Currency.html#byr/1"},{"type":"function","title":"Money.Currency.bzd/1","doc":"Convenience method to create a Money object for the Belize Dollar (BZD) currency. Examples iex&gt; Money.Currency . bzd ( 100 ) % Money { amount : 100 , currency : :BZD }","ref":"Money.Currency.html#bzd/1"},{"type":"function","title":"Money.Currency.cad/1","doc":"Convenience method to create a Money object for the Canadian Dollar (CAD) currency. Examples iex&gt; Money.Currency . cad ( 100 ) % Money { amount : 100 , currency : :CAD }","ref":"Money.Currency.html#cad/1"},{"type":"function","title":"Money.Currency.cdf/1","doc":"Convenience method to create a Money object for the Congolese Franc (CDF) currency. Examples iex&gt; Money.Currency . cdf ( 100 ) % Money { amount : 100 , currency : :CDF }","ref":"Money.Currency.html#cdf/1"},{"type":"function","title":"Money.Currency.chf/1","doc":"Convenience method to create a Money object for the Swiss Franc (CHF) currency. Examples iex&gt; Money.Currency . chf ( 100 ) % Money { amount : 100 , currency : :CHF }","ref":"Money.Currency.html#chf/1"},{"type":"function","title":"Money.Currency.clf/1","doc":"Convenience method to create a Money object for the Chilean Peso Unidades de fomento (CLF) currency. Examples iex&gt; Money.Currency . clf ( 100 ) % Money { amount : 100 , currency : :CLF }","ref":"Money.Currency.html#clf/1"},{"type":"function","title":"Money.Currency.clp/1","doc":"Convenience method to create a Money object for the Chilean Peso Unidades de fomento (CLP) currency. Examples iex&gt; Money.Currency . clp ( 100 ) % Money { amount : 100 , currency : :CLP }","ref":"Money.Currency.html#clp/1"},{"type":"function","title":"Money.Currency.cny/1","doc":"Convenience method to create a Money object for the Yuan Renminbi (CNY) currency. Examples iex&gt; Money.Currency . cny ( 100 ) % Money { amount : 100 , currency : :CNY }","ref":"Money.Currency.html#cny/1"},{"type":"function","title":"Money.Currency.cop/1","doc":"Convenience method to create a Money object for the Colombian Peso (COP) currency. Examples iex&gt; Money.Currency . cop ( 100 ) % Money { amount : 100 , currency : :COP }","ref":"Money.Currency.html#cop/1"},{"type":"function","title":"Money.Currency.cou/1","doc":"Convenience method to create a Money object for the Colombian Peso Unidad de Valor Real (COU) currency. Examples iex&gt; Money.Currency . cou ( 100 ) % Money { amount : 100 , currency : :COU }","ref":"Money.Currency.html#cou/1"},{"type":"function","title":"Money.Currency.crc/1","doc":"Convenience method to create a Money object for the Costa Rican Colon (CRC) currency. Examples iex&gt; Money.Currency . crc ( 100 ) % Money { amount : 100 , currency : :CRC }","ref":"Money.Currency.html#crc/1"},{"type":"function","title":"Money.Currency.cuc/1","doc":"Convenience method to create a Money object for the Cuban Peso Peso Convertible (CUC) currency. Examples iex&gt; Money.Currency . cuc ( 100 ) % Money { amount : 100 , currency : :CUC }","ref":"Money.Currency.html#cuc/1"},{"type":"function","title":"Money.Currency.cup/1","doc":"Convenience method to create a Money object for the Cuban Peso Peso Convertible (CUP) currency. Examples iex&gt; Money.Currency . cup ( 100 ) % Money { amount : 100 , currency : :CUP }","ref":"Money.Currency.html#cup/1"},{"type":"function","title":"Money.Currency.cve/1","doc":"Convenience method to create a Money object for the Cape Verde Escudo (CVE) currency. Examples iex&gt; Money.Currency . cve ( 100 ) % Money { amount : 100 , currency : :CVE }","ref":"Money.Currency.html#cve/1"},{"type":"function","title":"Money.Currency.czk/1","doc":"Convenience method to create a Money object for the Czech Koruna (CZK) currency. Examples iex&gt; Money.Currency . czk ( 100 ) % Money { amount : 100 , currency : :CZK }","ref":"Money.Currency.html#czk/1"},{"type":"function","title":"Money.Currency.djf/1","doc":"Convenience method to create a Money object for the Djibouti Franc (DJF) currency. Examples iex&gt; Money.Currency . djf ( 100 ) % Money { amount : 100 , currency : :DJF }","ref":"Money.Currency.html#djf/1"},{"type":"function","title":"Money.Currency.dkk/1","doc":"Convenience method to create a Money object for the Danish Krone (DKK) currency. Examples iex&gt; Money.Currency . dkk ( 100 ) % Money { amount : 100 , currency : :DKK }","ref":"Money.Currency.html#dkk/1"},{"type":"function","title":"Money.Currency.dop/1","doc":"Convenience method to create a Money object for the Dominican Peso (DOP) currency. Examples iex&gt; Money.Currency . dop ( 100 ) % Money { amount : 100 , currency : :DOP }","ref":"Money.Currency.html#dop/1"},{"type":"function","title":"Money.Currency.dzd/1","doc":"Convenience method to create a Money object for the Algerian Dinar (DZD) currency. Examples iex&gt; Money.Currency . dzd ( 100 ) % Money { amount : 100 , currency : :DZD }","ref":"Money.Currency.html#dzd/1"},{"type":"function","title":"Money.Currency.eek/1","doc":"Convenience method to create a Money object for the Kroon (EEK) currency. Examples iex&gt; Money.Currency . eek ( 100 ) % Money { amount : 100 , currency : :EEK }","ref":"Money.Currency.html#eek/1"},{"type":"function","title":"Money.Currency.egp/1","doc":"Convenience method to create a Money object for the Egyptian Pound (EGP) currency. Examples iex&gt; Money.Currency . egp ( 100 ) % Money { amount : 100 , currency : :EGP }","ref":"Money.Currency.html#egp/1"},{"type":"function","title":"Money.Currency.ern/1","doc":"Convenience method to create a Money object for the Nakfa (ERN) currency. Examples iex&gt; Money.Currency . ern ( 100 ) % Money { amount : 100 , currency : :ERN }","ref":"Money.Currency.html#ern/1"},{"type":"function","title":"Money.Currency.etb/1","doc":"Convenience method to create a Money object for the Ethiopian Birr (ETB) currency. Examples iex&gt; Money.Currency . etb ( 100 ) % Money { amount : 100 , currency : :ETB }","ref":"Money.Currency.html#etb/1"},{"type":"function","title":"Money.Currency.eur/1","doc":"Convenience method to create a Money object for the Euro (EUR) currency. Examples iex&gt; Money.Currency . eur ( 100 ) % Money { amount : 100 , currency : :EUR }","ref":"Money.Currency.html#eur/1"},{"type":"function","title":"Money.Currency.exists?/1","doc":"Returns true if a currency is defined Examples iex&gt; Money.Currency . exists? ( :USD ) true iex&gt; Money.Currency . exists? ( &quot;USD&quot; ) true iex&gt; Money.Currency . exists? ( :WRONG ) false","ref":"Money.Currency.html#exists?/1"},{"type":"function","title":"Money.Currency.exponent/1","doc":"Returns the exponent of the currency or nil if it doesn’t exist. Examples iex&gt; Money.Currency . exponent ( :USD ) 2 iex&gt; Money.Currency . exponent ( :WRONG ) nil","ref":"Money.Currency.html#exponent/1"},{"type":"function","title":"Money.Currency.exponent!/1","doc":"Returns the exponent of the currency. An ArgumentError is raised if the currency doesn’t exist. Examples iex&gt; Money.Currency . exponent! ( :USD ) 2 iex&gt; Money.Currency . exponent! ( :WRONG ) ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#exponent!/1"},{"type":"function","title":"Money.Currency.fjd/1","doc":"Convenience method to create a Money object for the Fiji Dollar (FJD) currency. Examples iex&gt; Money.Currency . fjd ( 100 ) % Money { amount : 100 , currency : :FJD }","ref":"Money.Currency.html#fjd/1"},{"type":"function","title":"Money.Currency.fkp/1","doc":"Convenience method to create a Money object for the Falkland Islands Pound (FKP) currency. Examples iex&gt; Money.Currency . fkp ( 100 ) % Money { amount : 100 , currency : :FKP }","ref":"Money.Currency.html#fkp/1"},{"type":"function","title":"Money.Currency.gbp/1","doc":"Convenience method to create a Money object for the Pound Sterling (GBP) currency. Examples iex&gt; Money.Currency . gbp ( 100 ) % Money { amount : 100 , currency : :GBP }","ref":"Money.Currency.html#gbp/1"},{"type":"function","title":"Money.Currency.gel/1","doc":"Convenience method to create a Money object for the Lari (GEL) currency. Examples iex&gt; Money.Currency . gel ( 100 ) % Money { amount : 100 , currency : :GEL }","ref":"Money.Currency.html#gel/1"},{"type":"function","title":"Money.Currency.get/1","doc":"Returns a map with the name and symbol of the currency or nil if it doesn’t exist. Examples iex&gt; Money.Currency . get ( :USD ) %{ name : &quot;US Dollar&quot; , symbol : &quot;$&quot; , exponent : 2 , number : 840 } iex&gt; Money.Currency . get ( :WRONG ) nil iex&gt; Money.Currency . get ( 826 ) %{ name : &quot;Pound Sterling&quot; , symbol : &quot;£&quot; , exponent : 2 , number : 826 }","ref":"Money.Currency.html#get/1"},{"type":"function","title":"Money.Currency.get!/1","doc":"Returns a map with the name and symbol of the currency. An ArgumentError is raised if the currency doesn’t exist. Examples iex&gt; Money.Currency . get! ( :USD ) %{ name : &quot;US Dollar&quot; , symbol : &quot;$&quot; , exponent : 2 , number : 840 } iex&gt; Money.Currency . get! ( :WRONG ) ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#get!/1"},{"type":"function","title":"Money.Currency.ghs/1","doc":"Convenience method to create a Money object for the Cedi (GHS) currency. Examples iex&gt; Money.Currency . ghs ( 100 ) % Money { amount : 100 , currency : :GHS }","ref":"Money.Currency.html#ghs/1"},{"type":"function","title":"Money.Currency.gip/1","doc":"Convenience method to create a Money object for the Gibraltar Pound (GIP) currency. Examples iex&gt; Money.Currency . gip ( 100 ) % Money { amount : 100 , currency : :GIP }","ref":"Money.Currency.html#gip/1"},{"type":"function","title":"Money.Currency.gmd/1","doc":"Convenience method to create a Money object for the Dalasi (GMD) currency. Examples iex&gt; Money.Currency . gmd ( 100 ) % Money { amount : 100 , currency : :GMD }","ref":"Money.Currency.html#gmd/1"},{"type":"function","title":"Money.Currency.gnf/1","doc":"Convenience method to create a Money object for the Guinea Franc (GNF) currency. Examples iex&gt; Money.Currency . gnf ( 100 ) % Money { amount : 100 , currency : :GNF }","ref":"Money.Currency.html#gnf/1"},{"type":"function","title":"Money.Currency.gtq/1","doc":"Convenience method to create a Money object for the Quetzal (GTQ) currency. Examples iex&gt; Money.Currency . gtq ( 100 ) % Money { amount : 100 , currency : :GTQ }","ref":"Money.Currency.html#gtq/1"},{"type":"function","title":"Money.Currency.gyd/1","doc":"Convenience method to create a Money object for the Guyana Dollar (GYD) currency. Examples iex&gt; Money.Currency . gyd ( 100 ) % Money { amount : 100 , currency : :GYD }","ref":"Money.Currency.html#gyd/1"},{"type":"function","title":"Money.Currency.hkd/1","doc":"Convenience method to create a Money object for the Hong Kong Dollar (HKD) currency. Examples iex&gt; Money.Currency . hkd ( 100 ) % Money { amount : 100 , currency : :HKD }","ref":"Money.Currency.html#hkd/1"},{"type":"function","title":"Money.Currency.hnl/1","doc":"Convenience method to create a Money object for the Lempira (HNL) currency. Examples iex&gt; Money.Currency . hnl ( 100 ) % Money { amount : 100 , currency : :HNL }","ref":"Money.Currency.html#hnl/1"},{"type":"function","title":"Money.Currency.hrk/1","doc":"Convenience method to create a Money object for the Croatian Kuna (HRK) currency. Examples iex&gt; Money.Currency . hrk ( 100 ) % Money { amount : 100 , currency : :HRK }","ref":"Money.Currency.html#hrk/1"},{"type":"function","title":"Money.Currency.htg/1","doc":"Convenience method to create a Money object for the Gourde US Dollar (HTG) currency. Examples iex&gt; Money.Currency . htg ( 100 ) % Money { amount : 100 , currency : :HTG }","ref":"Money.Currency.html#htg/1"},{"type":"function","title":"Money.Currency.huf/1","doc":"Convenience method to create a Money object for the Forint (HUF) currency. Examples iex&gt; Money.Currency . huf ( 100 ) % Money { amount : 100 , currency : :HUF }","ref":"Money.Currency.html#huf/1"},{"type":"function","title":"Money.Currency.idr/1","doc":"Convenience method to create a Money object for the Rupiah (IDR) currency. Examples iex&gt; Money.Currency . idr ( 100 ) % Money { amount : 100 , currency : :IDR }","ref":"Money.Currency.html#idr/1"},{"type":"function","title":"Money.Currency.ils/1","doc":"Convenience method to create a Money object for the New Israeli Sheqel (ILS) currency. Examples iex&gt; Money.Currency . ils ( 100 ) % Money { amount : 100 , currency : :ILS }","ref":"Money.Currency.html#ils/1"},{"type":"function","title":"Money.Currency.inr/1","doc":"Convenience method to create a Money object for the Indian Rupee (INR) currency. Examples iex&gt; Money.Currency . inr ( 100 ) % Money { amount : 100 , currency : :INR }","ref":"Money.Currency.html#inr/1"},{"type":"function","title":"Money.Currency.iqd/1","doc":"Convenience method to create a Money object for the Iraqi Dinar (IQD) currency. Examples iex&gt; Money.Currency . iqd ( 100 ) % Money { amount : 100 , currency : :IQD }","ref":"Money.Currency.html#iqd/1"},{"type":"function","title":"Money.Currency.irr/1","doc":"Convenience method to create a Money object for the Iranian Rial (IRR) currency. Examples iex&gt; Money.Currency . irr ( 100 ) % Money { amount : 100 , currency : :IRR }","ref":"Money.Currency.html#irr/1"},{"type":"function","title":"Money.Currency.isk/1","doc":"Convenience method to create a Money object for the Iceland Krona (ISK) currency. Examples iex&gt; Money.Currency . isk ( 100 ) % Money { amount : 100 , currency : :ISK }","ref":"Money.Currency.html#isk/1"},{"type":"function","title":"Money.Currency.jmd/1","doc":"Convenience method to create a Money object for the Jamaican Dollar (JMD) currency. Examples iex&gt; Money.Currency . jmd ( 100 ) % Money { amount : 100 , currency : :JMD }","ref":"Money.Currency.html#jmd/1"},{"type":"function","title":"Money.Currency.jod/1","doc":"Convenience method to create a Money object for the Jordanian Dinar (JOD) currency. Examples iex&gt; Money.Currency . jod ( 100 ) % Money { amount : 100 , currency : :JOD }","ref":"Money.Currency.html#jod/1"},{"type":"function","title":"Money.Currency.jpy/1","doc":"Convenience method to create a Money object for the Yen (JPY) currency. Examples iex&gt; Money.Currency . jpy ( 100 ) % Money { amount : 100 , currency : :JPY }","ref":"Money.Currency.html#jpy/1"},{"type":"function","title":"Money.Currency.kes/1","doc":"Convenience method to create a Money object for the Kenyan Shilling (KES) currency. Examples iex&gt; Money.Currency . kes ( 100 ) % Money { amount : 100 , currency : :KES }","ref":"Money.Currency.html#kes/1"},{"type":"function","title":"Money.Currency.kgs/1","doc":"Convenience method to create a Money object for the Som (KGS) currency. Examples iex&gt; Money.Currency . kgs ( 100 ) % Money { amount : 100 , currency : :KGS }","ref":"Money.Currency.html#kgs/1"},{"type":"function","title":"Money.Currency.khr/1","doc":"Convenience method to create a Money object for the Riel (KHR) currency. Examples iex&gt; Money.Currency . khr ( 100 ) % Money { amount : 100 , currency : :KHR }","ref":"Money.Currency.html#khr/1"},{"type":"function","title":"Money.Currency.kmf/1","doc":"Convenience method to create a Money object for the Comoro Franc (KMF) currency. Examples iex&gt; Money.Currency . kmf ( 100 ) % Money { amount : 100 , currency : :KMF }","ref":"Money.Currency.html#kmf/1"},{"type":"function","title":"Money.Currency.kpw/1","doc":"Convenience method to create a Money object for the North Korean Won (KPW) currency. Examples iex&gt; Money.Currency . kpw ( 100 ) % Money { amount : 100 , currency : :KPW }","ref":"Money.Currency.html#kpw/1"},{"type":"function","title":"Money.Currency.krw/1","doc":"Convenience method to create a Money object for the Won (KRW) currency. Examples iex&gt; Money.Currency . krw ( 100 ) % Money { amount : 100 , currency : :KRW }","ref":"Money.Currency.html#krw/1"},{"type":"function","title":"Money.Currency.kwd/1","doc":"Convenience method to create a Money object for the Kuwaiti Dinar (KWD) currency. Examples iex&gt; Money.Currency . kwd ( 100 ) % Money { amount : 100 , currency : :KWD }","ref":"Money.Currency.html#kwd/1"},{"type":"function","title":"Money.Currency.kyd/1","doc":"Convenience method to create a Money object for the Cayman Islands Dollar (KYD) currency. Examples iex&gt; Money.Currency . kyd ( 100 ) % Money { amount : 100 , currency : :KYD }","ref":"Money.Currency.html#kyd/1"},{"type":"function","title":"Money.Currency.kzt/1","doc":"Convenience method to create a Money object for the Tenge (KZT) currency. Examples iex&gt; Money.Currency . kzt ( 100 ) % Money { amount : 100 , currency : :KZT }","ref":"Money.Currency.html#kzt/1"},{"type":"function","title":"Money.Currency.lak/1","doc":"Convenience method to create a Money object for the Kip (LAK) currency. Examples iex&gt; Money.Currency . lak ( 100 ) % Money { amount : 100 , currency : :LAK }","ref":"Money.Currency.html#lak/1"},{"type":"function","title":"Money.Currency.lbp/1","doc":"Convenience method to create a Money object for the Lebanese Pound (LBP) currency. Examples iex&gt; Money.Currency . lbp ( 100 ) % Money { amount : 100 , currency : :LBP }","ref":"Money.Currency.html#lbp/1"},{"type":"function","title":"Money.Currency.lkr/1","doc":"Convenience method to create a Money object for the Sri Lanka Rupee (LKR) currency. Examples iex&gt; Money.Currency . lkr ( 100 ) % Money { amount : 100 , currency : :LKR }","ref":"Money.Currency.html#lkr/1"},{"type":"function","title":"Money.Currency.lrd/1","doc":"Convenience method to create a Money object for the Liberian Dollar (LRD) currency. Examples iex&gt; Money.Currency . lrd ( 100 ) % Money { amount : 100 , currency : :LRD }","ref":"Money.Currency.html#lrd/1"},{"type":"function","title":"Money.Currency.lsl/1","doc":"Convenience method to create a Money object for the Rand Loti (LSL) currency. Examples iex&gt; Money.Currency . lsl ( 100 ) % Money { amount : 100 , currency : :LSL }","ref":"Money.Currency.html#lsl/1"},{"type":"function","title":"Money.Currency.ltl/1","doc":"Convenience method to create a Money object for the Lithuanian Litas (LTL) currency. Examples iex&gt; Money.Currency . ltl ( 100 ) % Money { amount : 100 , currency : :LTL }","ref":"Money.Currency.html#ltl/1"},{"type":"function","title":"Money.Currency.lvl/1","doc":"Convenience method to create a Money object for the Latvian Lats (LVL) currency. Examples iex&gt; Money.Currency . lvl ( 100 ) % Money { amount : 100 , currency : :LVL }","ref":"Money.Currency.html#lvl/1"},{"type":"function","title":"Money.Currency.lyd/1","doc":"Convenience method to create a Money object for the Libyan Dinar (LYD) currency. Examples iex&gt; Money.Currency . lyd ( 100 ) % Money { amount : 100 , currency : :LYD }","ref":"Money.Currency.html#lyd/1"},{"type":"function","title":"Money.Currency.mad/1","doc":"Convenience method to create a Money object for the Moroccan Dirham (MAD) currency. Examples iex&gt; Money.Currency . mad ( 100 ) % Money { amount : 100 , currency : :MAD }","ref":"Money.Currency.html#mad/1"},{"type":"function","title":"Money.Currency.mdl/1","doc":"Convenience method to create a Money object for the Moldovan Leu (MDL) currency. Examples iex&gt; Money.Currency . mdl ( 100 ) % Money { amount : 100 , currency : :MDL }","ref":"Money.Currency.html#mdl/1"},{"type":"function","title":"Money.Currency.mga/1","doc":"Convenience method to create a Money object for the Malagasy Ariary (MGA) currency. Examples iex&gt; Money.Currency . mga ( 100 ) % Money { amount : 100 , currency : :MGA }","ref":"Money.Currency.html#mga/1"},{"type":"function","title":"Money.Currency.mkd/1","doc":"Convenience method to create a Money object for the Denar (MKD) currency. Examples iex&gt; Money.Currency . mkd ( 100 ) % Money { amount : 100 , currency : :MKD }","ref":"Money.Currency.html#mkd/1"},{"type":"function","title":"Money.Currency.mmk/1","doc":"Convenience method to create a Money object for the Kyat (MMK) currency. Examples iex&gt; Money.Currency . mmk ( 100 ) % Money { amount : 100 , currency : :MMK }","ref":"Money.Currency.html#mmk/1"},{"type":"function","title":"Money.Currency.mnt/1","doc":"Convenience method to create a Money object for the Tugrik (MNT) currency. Examples iex&gt; Money.Currency . mnt ( 100 ) % Money { amount : 100 , currency : :MNT }","ref":"Money.Currency.html#mnt/1"},{"type":"function","title":"Money.Currency.mop/1","doc":"Convenience method to create a Money object for the Pataca (MOP) currency. Examples iex&gt; Money.Currency . mop ( 100 ) % Money { amount : 100 , currency : :MOP }","ref":"Money.Currency.html#mop/1"},{"type":"function","title":"Money.Currency.mro/1","doc":"Convenience method to create a Money object for the Ouguiya (MRO) currency. Examples iex&gt; Money.Currency . mro ( 100 ) % Money { amount : 100 , currency : :MRO }","ref":"Money.Currency.html#mro/1"},{"type":"function","title":"Money.Currency.mru/1","doc":"Convenience method to create a Money object for the Ouguiya (MRU) currency. Examples iex&gt; Money.Currency . mru ( 100 ) % Money { amount : 100 , currency : :MRU }","ref":"Money.Currency.html#mru/1"},{"type":"function","title":"Money.Currency.mur/1","doc":"Convenience method to create a Money object for the Mauritius Rupee (MUR) currency. Examples iex&gt; Money.Currency . mur ( 100 ) % Money { amount : 100 , currency : :MUR }","ref":"Money.Currency.html#mur/1"},{"type":"function","title":"Money.Currency.mvr/1","doc":"Convenience method to create a Money object for the Rufiyaa (MVR) currency. Examples iex&gt; Money.Currency . mvr ( 100 ) % Money { amount : 100 , currency : :MVR }","ref":"Money.Currency.html#mvr/1"},{"type":"function","title":"Money.Currency.mwk/1","doc":"Convenience method to create a Money object for the Kwacha (MWK) currency. Examples iex&gt; Money.Currency . mwk ( 100 ) % Money { amount : 100 , currency : :MWK }","ref":"Money.Currency.html#mwk/1"},{"type":"function","title":"Money.Currency.mxn/1","doc":"Convenience method to create a Money object for the Mexican Peso (MXN) currency. Examples iex&gt; Money.Currency . mxn ( 100 ) % Money { amount : 100 , currency : :MXN }","ref":"Money.Currency.html#mxn/1"},{"type":"function","title":"Money.Currency.mxv/1","doc":"Convenience method to create a Money object for the Mexican Peso Mexican Unidad de Inversion (UDI) (MXV) currency. Examples iex&gt; Money.Currency . mxv ( 100 ) % Money { amount : 100 , currency : :MXV }","ref":"Money.Currency.html#mxv/1"},{"type":"function","title":"Money.Currency.myr/1","doc":"Convenience method to create a Money object for the Malaysian Ringgit (MYR) currency. Examples iex&gt; Money.Currency . myr ( 100 ) % Money { amount : 100 , currency : :MYR }","ref":"Money.Currency.html#myr/1"},{"type":"function","title":"Money.Currency.mzn/1","doc":"Convenience method to create a Money object for the Metical (MZN) currency. Examples iex&gt; Money.Currency . mzn ( 100 ) % Money { amount : 100 , currency : :MZN }","ref":"Money.Currency.html#mzn/1"},{"type":"function","title":"Money.Currency.nad/1","doc":"Convenience method to create a Money object for the Rand Namibia Dollar (NAD) currency. Examples iex&gt; Money.Currency . nad ( 100 ) % Money { amount : 100 , currency : :NAD }","ref":"Money.Currency.html#nad/1"},{"type":"function","title":"Money.Currency.name/1","doc":"Returns the name of the currency or nil if it doesn’t exist. Examples iex&gt; Money.Currency . name ( :USD ) &quot;US Dollar&quot; iex&gt; Money.Currency . name ( :WRONG ) nil","ref":"Money.Currency.html#name/1"},{"type":"function","title":"Money.Currency.name!/1","doc":"Returns the name of the currency. An ArgumentError is raised if the currency doesn’t exist. Examples iex&gt; Money.Currency . name! ( :USD ) &quot;US Dollar&quot; iex&gt; Money.Currency . name! ( :WRONG ) ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#name!/1"},{"type":"function","title":"Money.Currency.ngn/1","doc":"Convenience method to create a Money object for the Naira (NGN) currency. Examples iex&gt; Money.Currency . ngn ( 100 ) % Money { amount : 100 , currency : :NGN }","ref":"Money.Currency.html#ngn/1"},{"type":"function","title":"Money.Currency.nio/1","doc":"Convenience method to create a Money object for the Cordoba Oro (NIO) currency. Examples iex&gt; Money.Currency . nio ( 100 ) % Money { amount : 100 , currency : :NIO }","ref":"Money.Currency.html#nio/1"},{"type":"function","title":"Money.Currency.nok/1","doc":"Convenience method to create a Money object for the Norwegian Krone (NOK) currency. Examples iex&gt; Money.Currency . nok ( 100 ) % Money { amount : 100 , currency : :NOK }","ref":"Money.Currency.html#nok/1"},{"type":"function","title":"Money.Currency.npr/1","doc":"Convenience method to create a Money object for the Nepalese Rupee (NPR) currency. Examples iex&gt; Money.Currency . npr ( 100 ) % Money { amount : 100 , currency : :NPR }","ref":"Money.Currency.html#npr/1"},{"type":"function","title":"Money.Currency.number/1","doc":"Returns the number of the currency or nil if it doesn’t exist. Examples iex&gt; Money.Currency . number ( :USD ) 840 iex&gt; Money.Currency . number ( :WRONG ) nil","ref":"Money.Currency.html#number/1"},{"type":"function","title":"Money.Currency.number!/1","doc":"Returns the number of the currency. An ArgumentError is raised if the currency doesn’t exist. Examples iex&gt; Money.Currency . number! ( :EUR ) 978 iex&gt; Money.Currency . exponent! ( :WRONG ) ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#number!/1"},{"type":"function","title":"Money.Currency.nzd/1","doc":"Convenience method to create a Money object for the New Zealand Dollar (NZD) currency. Examples iex&gt; Money.Currency . nzd ( 100 ) % Money { amount : 100 , currency : :NZD }","ref":"Money.Currency.html#nzd/1"},{"type":"function","title":"Money.Currency.omr/1","doc":"Convenience method to create a Money object for the Rial Omani (OMR) currency. Examples iex&gt; Money.Currency . omr ( 100 ) % Money { amount : 100 , currency : :OMR }","ref":"Money.Currency.html#omr/1"},{"type":"function","title":"Money.Currency.pab/1","doc":"Convenience method to create a Money object for the Balboa US Dollar (PAB) currency. Examples iex&gt; Money.Currency . pab ( 100 ) % Money { amount : 100 , currency : :PAB }","ref":"Money.Currency.html#pab/1"},{"type":"function","title":"Money.Currency.pen/1","doc":"Convenience method to create a Money object for the Nuevo Sol (PEN) currency. Examples iex&gt; Money.Currency . pen ( 100 ) % Money { amount : 100 , currency : :PEN }","ref":"Money.Currency.html#pen/1"},{"type":"function","title":"Money.Currency.pgk/1","doc":"Convenience method to create a Money object for the Kina (PGK) currency. Examples iex&gt; Money.Currency . pgk ( 100 ) % Money { amount : 100 , currency : :PGK }","ref":"Money.Currency.html#pgk/1"},{"type":"function","title":"Money.Currency.php/1","doc":"Convenience method to create a Money object for the Philippine Peso (PHP) currency. Examples iex&gt; Money.Currency . php ( 100 ) % Money { amount : 100 , currency : :PHP }","ref":"Money.Currency.html#php/1"},{"type":"function","title":"Money.Currency.pkr/1","doc":"Convenience method to create a Money object for the Pakistan Rupee (PKR) currency. Examples iex&gt; Money.Currency . pkr ( 100 ) % Money { amount : 100 , currency : :PKR }","ref":"Money.Currency.html#pkr/1"},{"type":"function","title":"Money.Currency.pln/1","doc":"Convenience method to create a Money object for the Zloty (PLN) currency. Examples iex&gt; Money.Currency . pln ( 100 ) % Money { amount : 100 , currency : :PLN }","ref":"Money.Currency.html#pln/1"},{"type":"function","title":"Money.Currency.pyg/1","doc":"Convenience method to create a Money object for the Guarani (PYG) currency. Examples iex&gt; Money.Currency . pyg ( 100 ) % Money { amount : 100 , currency : :PYG }","ref":"Money.Currency.html#pyg/1"},{"type":"function","title":"Money.Currency.qar/1","doc":"Convenience method to create a Money object for the Qatari Rial (QAR) currency. Examples iex&gt; Money.Currency . qar ( 100 ) % Money { amount : 100 , currency : :QAR }","ref":"Money.Currency.html#qar/1"},{"type":"function","title":"Money.Currency.ron/1","doc":"Convenience method to create a Money object for the New Leu (RON) currency. Examples iex&gt; Money.Currency . ron ( 100 ) % Money { amount : 100 , currency : :RON }","ref":"Money.Currency.html#ron/1"},{"type":"function","title":"Money.Currency.rsd/1","doc":"Convenience method to create a Money object for the Serbian Dinar (RSD) currency. Examples iex&gt; Money.Currency . rsd ( 100 ) % Money { amount : 100 , currency : :RSD }","ref":"Money.Currency.html#rsd/1"},{"type":"function","title":"Money.Currency.rub/1","doc":"Convenience method to create a Money object for the Russian Ruble (RUB) currency. Examples iex&gt; Money.Currency . rub ( 100 ) % Money { amount : 100 , currency : :RUB }","ref":"Money.Currency.html#rub/1"},{"type":"function","title":"Money.Currency.rwf/1","doc":"Convenience method to create a Money object for the Rwanda Franc (RWF) currency. Examples iex&gt; Money.Currency . rwf ( 100 ) % Money { amount : 100 , currency : :RWF }","ref":"Money.Currency.html#rwf/1"},{"type":"function","title":"Money.Currency.sar/1","doc":"Convenience method to create a Money object for the Saudi Riyal (SAR) currency. Examples iex&gt; Money.Currency . sar ( 100 ) % Money { amount : 100 , currency : :SAR }","ref":"Money.Currency.html#sar/1"},{"type":"function","title":"Money.Currency.sbd/1","doc":"Convenience method to create a Money object for the Solomon Islands Dollar (SBD) currency. Examples iex&gt; Money.Currency . sbd ( 100 ) % Money { amount : 100 , currency : :SBD }","ref":"Money.Currency.html#sbd/1"},{"type":"function","title":"Money.Currency.scr/1","doc":"Convenience method to create a Money object for the Seychelles Rupee (SCR) currency. Examples iex&gt; Money.Currency . scr ( 100 ) % Money { amount : 100 , currency : :SCR }","ref":"Money.Currency.html#scr/1"},{"type":"function","title":"Money.Currency.sdg/1","doc":"Convenience method to create a Money object for the Sudanese Pound (SDG) currency. Examples iex&gt; Money.Currency . sdg ( 100 ) % Money { amount : 100 , currency : :SDG }","ref":"Money.Currency.html#sdg/1"},{"type":"function","title":"Money.Currency.sek/1","doc":"Convenience method to create a Money object for the Swedish Krona (SEK) currency. Examples iex&gt; Money.Currency . sek ( 100 ) % Money { amount : 100 , currency : :SEK }","ref":"Money.Currency.html#sek/1"},{"type":"function","title":"Money.Currency.sgd/1","doc":"Convenience method to create a Money object for the Singapore Dollar (SGD) currency. Examples iex&gt; Money.Currency . sgd ( 100 ) % Money { amount : 100 , currency : :SGD }","ref":"Money.Currency.html#sgd/1"},{"type":"function","title":"Money.Currency.shp/1","doc":"Convenience method to create a Money object for the Saint Helena Pound (SHP) currency. Examples iex&gt; Money.Currency . shp ( 100 ) % Money { amount : 100 , currency : :SHP }","ref":"Money.Currency.html#shp/1"},{"type":"function","title":"Money.Currency.sle/1","doc":"Convenience method to create a Money object for the Leone (SLE) currency. Examples iex&gt; Money.Currency . sle ( 100 ) % Money { amount : 100 , currency : :SLE }","ref":"Money.Currency.html#sle/1"},{"type":"function","title":"Money.Currency.sll/1","doc":"Convenience method to create a Money object for the Leone (SLL) currency. Examples iex&gt; Money.Currency . sll ( 100 ) % Money { amount : 100 , currency : :SLL }","ref":"Money.Currency.html#sll/1"},{"type":"function","title":"Money.Currency.sos/1","doc":"Convenience method to create a Money object for the Somali Shilling (SOS) currency. Examples iex&gt; Money.Currency . sos ( 100 ) % Money { amount : 100 , currency : :SOS }","ref":"Money.Currency.html#sos/1"},{"type":"function","title":"Money.Currency.srd/1","doc":"Convenience method to create a Money object for the Surinam Dollar (SRD) currency. Examples iex&gt; Money.Currency . srd ( 100 ) % Money { amount : 100 , currency : :SRD }","ref":"Money.Currency.html#srd/1"},{"type":"function","title":"Money.Currency.ssp/1","doc":"Convenience method to create a Money object for the South Sudanese Pound (SSP) currency. Examples iex&gt; Money.Currency . ssp ( 100 ) % Money { amount : 100 , currency : :SSP }","ref":"Money.Currency.html#ssp/1"},{"type":"function","title":"Money.Currency.std/1","doc":"Convenience method to create a Money object for the Dobra (STD) currency. Examples iex&gt; Money.Currency . std ( 100 ) % Money { amount : 100 , currency : :STD }","ref":"Money.Currency.html#std/1"},{"type":"function","title":"Money.Currency.stn/1","doc":"Convenience method to create a Money object for the Dobra (STN) currency. Examples iex&gt; Money.Currency . stn ( 100 ) % Money { amount : 100 , currency : :STN }","ref":"Money.Currency.html#stn/1"},{"type":"function","title":"Money.Currency.sub_units_count!/1","doc":"Returns the sub_units_count of the currency. An ArgumentError is raised if the currency doesn’t exist. Examples iex&gt; Money.Currency . sub_units_count! ( :USD ) 100 iex&gt; Money.Currency . sub_units_count! ( :JPY ) 1 iex&gt; Money.Currency . sub_units_count! ( :WRONG ) ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#sub_units_count!/1"},{"type":"function","title":"Money.Currency.svc/1","doc":"Convenience method to create a Money object for the El Salvador Colon US Dollar (SVC) currency. Examples iex&gt; Money.Currency . svc ( 100 ) % Money { amount : 100 , currency : :SVC }","ref":"Money.Currency.html#svc/1"},{"type":"function","title":"Money.Currency.symbol/1","doc":"Returns the symbol of the currency or nil if it doesn’t exist. Examples iex&gt; Money.Currency . symbol ( :USD ) &quot;$&quot; iex&gt; Money.Currency . symbol ( :WRONG ) nil","ref":"Money.Currency.html#symbol/1"},{"type":"function","title":"Money.Currency.symbol!/1","doc":"Returns the symbol of the currency. An ArgumentError is raised if the currency doesn’t exist. Examples iex&gt; Money.Currency . symbol! ( :USD ) &quot;$&quot; iex&gt; Money.Currency . symbol! ( :WRONG ) ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#symbol!/1"},{"type":"function","title":"Money.Currency.syp/1","doc":"Convenience method to create a Money object for the Syrian Pound (SYP) currency. Examples iex&gt; Money.Currency . syp ( 100 ) % Money { amount : 100 , currency : :SYP }","ref":"Money.Currency.html#syp/1"},{"type":"function","title":"Money.Currency.szl/1","doc":"Convenience method to create a Money object for the Lilangeni (SZL) currency. Examples iex&gt; Money.Currency . szl ( 100 ) % Money { amount : 100 , currency : :SZL }","ref":"Money.Currency.html#szl/1"},{"type":"function","title":"Money.Currency.thb/1","doc":"Convenience method to create a Money object for the Baht (THB) currency. Examples iex&gt; Money.Currency . thb ( 100 ) % Money { amount : 100 , currency : :THB }","ref":"Money.Currency.html#thb/1"},{"type":"function","title":"Money.Currency.tjs/1","doc":"Convenience method to create a Money object for the Somoni (TJS) currency. Examples iex&gt; Money.Currency . tjs ( 100 ) % Money { amount : 100 , currency : :TJS }","ref":"Money.Currency.html#tjs/1"},{"type":"function","title":"Money.Currency.tmt/1","doc":"Convenience method to create a Money object for the Manat (TMT) currency. Examples iex&gt; Money.Currency . tmt ( 100 ) % Money { amount : 100 , currency : :TMT }","ref":"Money.Currency.html#tmt/1"},{"type":"function","title":"Money.Currency.tnd/1","doc":"Convenience method to create a Money object for the Tunisian Dinar (TND) currency. Examples iex&gt; Money.Currency . tnd ( 100 ) % Money { amount : 100 , currency : :TND }","ref":"Money.Currency.html#tnd/1"},{"type":"function","title":"Money.Currency.to_atom/1","doc":"Returns the atom representation of the currency key An ArgumentError is raised if the currency doesn’t exist. Examples iex&gt; Money.Currency . to_atom ( &quot;usd&quot; ) :USD iex&gt; Money.Currency . to_atom ( :WRONG ) ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#to_atom/1"},{"type":"function","title":"Money.Currency.top/1","doc":"Convenience method to create a Money object for the Pa'anga (TOP) currency. Examples iex&gt; Money.Currency . top ( 100 ) % Money { amount : 100 , currency : :TOP }","ref":"Money.Currency.html#top/1"},{"type":"function","title":"Money.Currency.try/1","doc":"Convenience method to create a Money object for the Turkish Lira (TRY) currency. Examples iex&gt; Money.Currency . try ( 100 ) % Money { amount : 100 , currency : :TRY }","ref":"Money.Currency.html#try/1"},{"type":"function","title":"Money.Currency.ttd/1","doc":"Convenience method to create a Money object for the Trinidad and Tobago Dollar (TTD) currency. Examples iex&gt; Money.Currency . ttd ( 100 ) % Money { amount : 100 , currency : :TTD }","ref":"Money.Currency.html#ttd/1"},{"type":"function","title":"Money.Currency.twd/1","doc":"Convenience method to create a Money object for the New Taiwan Dollar (TWD) currency. Examples iex&gt; Money.Currency . twd ( 100 ) % Money { amount : 100 , currency : :TWD }","ref":"Money.Currency.html#twd/1"},{"type":"function","title":"Money.Currency.tzs/1","doc":"Convenience method to create a Money object for the Tanzanian Shilling (TZS) currency. Examples iex&gt; Money.Currency . tzs ( 100 ) % Money { amount : 100 , currency : :TZS }","ref":"Money.Currency.html#tzs/1"},{"type":"function","title":"Money.Currency.uah/1","doc":"Convenience method to create a Money object for the Hryvnia (UAH) currency. Examples iex&gt; Money.Currency . uah ( 100 ) % Money { amount : 100 , currency : :UAH }","ref":"Money.Currency.html#uah/1"},{"type":"function","title":"Money.Currency.ugx/1","doc":"Convenience method to create a Money object for the Uganda Shilling (UGX) currency. Examples iex&gt; Money.Currency . ugx ( 100 ) % Money { amount : 100 , currency : :UGX }","ref":"Money.Currency.html#ugx/1"},{"type":"function","title":"Money.Currency.usd/1","doc":"Convenience method to create a Money object for the US Dollar (USD) currency. Examples iex&gt; Money.Currency . usd ( 100 ) % Money { amount : 100 , currency : :USD }","ref":"Money.Currency.html#usd/1"},{"type":"function","title":"Money.Currency.usn/1","doc":"Convenience method to create a Money object for the US Dollar next-day funds (USN) currency. Examples iex&gt; Money.Currency . usn ( 100 ) % Money { amount : 100 , currency : :USN }","ref":"Money.Currency.html#usn/1"},{"type":"function","title":"Money.Currency.uyi/1","doc":"Convenience method to create a Money object for the Peso Uruguayo Uruguay Peso en Unidades Indexadas (UYI) currency. Examples iex&gt; Money.Currency . uyi ( 100 ) % Money { amount : 100 , currency : :UYI }","ref":"Money.Currency.html#uyi/1"},{"type":"function","title":"Money.Currency.uyu/1","doc":"Convenience method to create a Money object for the Peso Uruguayo Uruguay Peso en Unidades Indexadas (UYU) currency. Examples iex&gt; Money.Currency . uyu ( 100 ) % Money { amount : 100 , currency : :UYU }","ref":"Money.Currency.html#uyu/1"},{"type":"function","title":"Money.Currency.uzs/1","doc":"Convenience method to create a Money object for the Uzbekistan Sum (UZS) currency. Examples iex&gt; Money.Currency . uzs ( 100 ) % Money { amount : 100 , currency : :UZS }","ref":"Money.Currency.html#uzs/1"},{"type":"function","title":"Money.Currency.vef/1","doc":"Convenience method to create a Money object for the Bolivar Fuerte (VEF) currency. Examples iex&gt; Money.Currency . vef ( 100 ) % Money { amount : 100 , currency : :VEF }","ref":"Money.Currency.html#vef/1"},{"type":"function","title":"Money.Currency.ves/1","doc":"Convenience method to create a Money object for the Venezuelan Bolivar Soberano (VES) currency. Examples iex&gt; Money.Currency . ves ( 100 ) % Money { amount : 100 , currency : :VES }","ref":"Money.Currency.html#ves/1"},{"type":"function","title":"Money.Currency.vnd/1","doc":"Convenience method to create a Money object for the Dong (VND) currency. Examples iex&gt; Money.Currency . vnd ( 100 ) % Money { amount : 100 , currency : :VND }","ref":"Money.Currency.html#vnd/1"},{"type":"function","title":"Money.Currency.vuv/1","doc":"Convenience method to create a Money object for the Vatu (VUV) currency. Examples iex&gt; Money.Currency . vuv ( 100 ) % Money { amount : 100 , currency : :VUV }","ref":"Money.Currency.html#vuv/1"},{"type":"function","title":"Money.Currency.wst/1","doc":"Convenience method to create a Money object for the Tala (WST) currency. Examples iex&gt; Money.Currency . wst ( 100 ) % Money { amount : 100 , currency : :WST }","ref":"Money.Currency.html#wst/1"},{"type":"function","title":"Money.Currency.xaf/1","doc":"Convenience method to create a Money object for the CFA Franc BEAC (XAF) currency. Examples iex&gt; Money.Currency . xaf ( 100 ) % Money { amount : 100 , currency : :XAF }","ref":"Money.Currency.html#xaf/1"},{"type":"function","title":"Money.Currency.xag/1","doc":"Convenience method to create a Money object for the Silver (XAG) currency. Examples iex&gt; Money.Currency . xag ( 100 ) % Money { amount : 100 , currency : :XAG }","ref":"Money.Currency.html#xag/1"},{"type":"function","title":"Money.Currency.xau/1","doc":"Convenience method to create a Money object for the Gold (XAU) currency. Examples iex&gt; Money.Currency . xau ( 100 ) % Money { amount : 100 , currency : :XAU }","ref":"Money.Currency.html#xau/1"},{"type":"function","title":"Money.Currency.xba/1","doc":"Convenience method to create a Money object for the Bond Markets Units European Composite Unit (EURCO) (XBA) currency. Examples iex&gt; Money.Currency . xba ( 100 ) % Money { amount : 100 , currency : :XBA }","ref":"Money.Currency.html#xba/1"},{"type":"function","title":"Money.Currency.xbb/1","doc":"Convenience method to create a Money object for the European Monetary Unit (E.M.U.-6) (XBB) currency. Examples iex&gt; Money.Currency . xbb ( 100 ) % Money { amount : 100 , currency : :XBB }","ref":"Money.Currency.html#xbb/1"},{"type":"function","title":"Money.Currency.xbc/1","doc":"Convenience method to create a Money object for the European Unit of Account 9(E.U.A.-9) (XBC) currency. Examples iex&gt; Money.Currency . xbc ( 100 ) % Money { amount : 100 , currency : :XBC }","ref":"Money.Currency.html#xbc/1"},{"type":"function","title":"Money.Currency.xbd/1","doc":"Convenience method to create a Money object for the European Unit of Account 17(E.U.A.-17) (XBD) currency. Examples iex&gt; Money.Currency . xbd ( 100 ) % Money { amount : 100 , currency : :XBD }","ref":"Money.Currency.html#xbd/1"},{"type":"function","title":"Money.Currency.xcd/1","doc":"Convenience method to create a Money object for the East Caribbean Dollar (XCD) currency. Examples iex&gt; Money.Currency . xcd ( 100 ) % Money { amount : 100 , currency : :XCD }","ref":"Money.Currency.html#xcd/1"},{"type":"function","title":"Money.Currency.xdr/1","doc":"Convenience method to create a Money object for the SDR (XDR) currency. Examples iex&gt; Money.Currency . xdr ( 100 ) % Money { amount : 100 , currency : :XDR }","ref":"Money.Currency.html#xdr/1"},{"type":"function","title":"Money.Currency.xfu/1","doc":"Convenience method to create a Money object for the UIC-Franc (XFU) currency. Examples iex&gt; Money.Currency . xfu ( 100 ) % Money { amount : 100 , currency : :XFU }","ref":"Money.Currency.html#xfu/1"},{"type":"function","title":"Money.Currency.xof/1","doc":"Convenience method to create a Money object for the CFA Franc BCEAO (XOF) currency. Examples iex&gt; Money.Currency . xof ( 100 ) % Money { amount : 100 , currency : :XOF }","ref":"Money.Currency.html#xof/1"},{"type":"function","title":"Money.Currency.xpd/1","doc":"Convenience method to create a Money object for the Palladium (XPD) currency. Examples iex&gt; Money.Currency . xpd ( 100 ) % Money { amount : 100 , currency : :XPD }","ref":"Money.Currency.html#xpd/1"},{"type":"function","title":"Money.Currency.xpf/1","doc":"Convenience method to create a Money object for the CFP Franc (XPF) currency. Examples iex&gt; Money.Currency . xpf ( 100 ) % Money { amount : 100 , currency : :XPF }","ref":"Money.Currency.html#xpf/1"},{"type":"function","title":"Money.Currency.xpt/1","doc":"Convenience method to create a Money object for the Platinum (XPT) currency. Examples iex&gt; Money.Currency . xpt ( 100 ) % Money { amount : 100 , currency : :XPT }","ref":"Money.Currency.html#xpt/1"},{"type":"function","title":"Money.Currency.xsu/1","doc":"Convenience method to create a Money object for the Sucre (XSU) currency. Examples iex&gt; Money.Currency . xsu ( 100 ) % Money { amount : 100 , currency : :XSU }","ref":"Money.Currency.html#xsu/1"},{"type":"function","title":"Money.Currency.xts/1","doc":"Convenience method to create a Money object for the Codes specifically reserved for testing purposes (XTS) currency. Examples iex&gt; Money.Currency . xts ( 100 ) % Money { amount : 100 , currency : :XTS }","ref":"Money.Currency.html#xts/1"},{"type":"function","title":"Money.Currency.xua/1","doc":"Convenience method to create a Money object for the ADB Unit of Account (XUA) currency. Examples iex&gt; Money.Currency . xua ( 100 ) % Money { amount : 100 , currency : :XUA }","ref":"Money.Currency.html#xua/1"},{"type":"function","title":"Money.Currency.yer/1","doc":"Convenience method to create a Money object for the Yemeni Rial (YER) currency. Examples iex&gt; Money.Currency . yer ( 100 ) % Money { amount : 100 , currency : :YER }","ref":"Money.Currency.html#yer/1"},{"type":"function","title":"Money.Currency.zar/1","doc":"Convenience method to create a Money object for the Rand (ZAR) currency. Examples iex&gt; Money.Currency . zar ( 100 ) % Money { amount : 100 , currency : :ZAR }","ref":"Money.Currency.html#zar/1"},{"type":"function","title":"Money.Currency.zmw/1","doc":"Convenience method to create a Money object for the Zambian Kwacha (ZMW) currency. Examples iex&gt; Money.Currency . zmw ( 100 ) % Money { amount : 100 , currency : :ZMW }","ref":"Money.Currency.html#zmw/1"},{"type":"function","title":"Money.Currency.zwl/1","doc":"Convenience method to create a Money object for the Zimbabwe Dollar (ZWL) currency. Examples iex&gt; Money.Currency . zwl ( 100 ) % Money { amount : 100 , currency : :ZWL }","ref":"Money.Currency.html#zwl/1"},{"type":"type","title":"Money.Currency.index_type/0","doc":"","ref":"Money.Currency.html#t:index_type/0"},{"type":"module","title":"Money.Currency.Ecto.Type","doc":"Provides a type for Ecto to store a currency. The underlying data type is a string. Migration create table ( :my_table ) do add :currency , :string end Schema schema &quot;my_table&quot; do field :currency , Money.Currency.Ecto.Type end","ref":"Money.Currency.Ecto.Type.html"},{"type":"function","title":"Money.Currency.Ecto.Type.cast/1","doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"Money.Currency.Ecto.Type.html#cast/1"},{"type":"function","title":"Money.Currency.Ecto.Type.dump/1","doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"Money.Currency.Ecto.Type.html#dump/1"},{"type":"function","title":"Money.Currency.Ecto.Type.embed_as/1","doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Money.Currency.Ecto.Type.html#embed_as/1"},{"type":"function","title":"Money.Currency.Ecto.Type.equal?/2","doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Money.Currency.Ecto.Type.html#equal?/2"},{"type":"function","title":"Money.Currency.Ecto.Type.load/1","doc":"Callback implementation for Ecto.Type.load/1 .","ref":"Money.Currency.Ecto.Type.html#load/1"},{"type":"function","title":"Money.Currency.Ecto.Type.type/0","doc":"Callback implementation for Ecto.Type.type/0 .","ref":"Money.Currency.Ecto.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Amount.Type","doc":"Provides a type for Ecto to store a amount. The underlying data type should be an integer. Migration create table ( :my_table ) do add :amount , :integer end Schema schema &quot;my_table&quot; do field :amount , Money.Ecto.Amount.Type end","ref":"Money.Ecto.Amount.Type.html"},{"type":"function","title":"Money.Ecto.Amount.Type.cast/1","doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"Money.Ecto.Amount.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Amount.Type.dump/1","doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"Money.Ecto.Amount.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Amount.Type.embed_as/1","doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Money.Ecto.Amount.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Amount.Type.equal?/2","doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Money.Ecto.Amount.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Amount.Type.load/1","doc":"Callback implementation for Ecto.Type.load/1 .","ref":"Money.Ecto.Amount.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Amount.Type.type/0","doc":"Callback implementation for Ecto.Type.type/0 .","ref":"Money.Ecto.Amount.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Composite.Type","doc":"Provides a type for Ecto to store a multi-currency price. The underlying data type should be an user-defined Postgres composite type :money_with_currency . Migration execute &quot;CREATE TYPE public.money_with_currency AS (amount integer, currency varchar(3))&quot; create table ( :my_table ) do add :price , :money_with_currency end Schema schema &quot;my_table&quot; do field :price , Money.Ecto.Composite.Type end","ref":"Money.Ecto.Composite.Type.html"},{"type":"function","title":"Money.Ecto.Composite.Type.cast/1","doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"Money.Ecto.Composite.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Composite.Type.dump/1","doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"Money.Ecto.Composite.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Composite.Type.embed_as/1","doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Money.Ecto.Composite.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Composite.Type.equal?/2","doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Money.Ecto.Composite.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Composite.Type.load/1","doc":"Callback implementation for Ecto.Type.load/1 .","ref":"Money.Ecto.Composite.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Composite.Type.type/0","doc":"Callback implementation for Ecto.Type.type/0 .","ref":"Money.Ecto.Composite.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Currency.Type","doc":"Provides a type for Ecto to store a currency. The underlying data type is a string. Migration create table ( :my_table ) do add :currency , :varchar , size : 3 end Schema schema &quot;my_table&quot; do field :currency , Money.Ecto.Currency.Type end","ref":"Money.Ecto.Currency.Type.html"},{"type":"function","title":"Money.Ecto.Currency.Type.cast/1","doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"Money.Ecto.Currency.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Currency.Type.dump/1","doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"Money.Ecto.Currency.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Currency.Type.embed_as/1","doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Money.Ecto.Currency.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Currency.Type.equal?/2","doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Money.Ecto.Currency.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Currency.Type.load/1","doc":"Callback implementation for Ecto.Type.load/1 .","ref":"Money.Ecto.Currency.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Currency.Type.type/0","doc":"Callback implementation for Ecto.Type.type/0 .","ref":"Money.Ecto.Currency.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Map.Type","doc":"Provides a type for Ecto to store a multi-currency price. The underlying data type should be a map(JSON). Suitable for databases that do not support composite types, but support JSON (e.g. MySQL). Migration create table ( :my_table ) do add :price , :map end Schema schema &quot;my_table&quot; do field :price , Money.Ecto.Map.Type end","ref":"Money.Ecto.Map.Type.html"},{"type":"function","title":"Money.Ecto.Map.Type.cast/1","doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"Money.Ecto.Map.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Map.Type.dump/1","doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"Money.Ecto.Map.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Map.Type.embed_as/1","doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Money.Ecto.Map.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Map.Type.equal?/2","doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Money.Ecto.Map.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Map.Type.load/1","doc":"Callback implementation for Ecto.Type.load/1 .","ref":"Money.Ecto.Map.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Map.Type.type/0","doc":"Callback implementation for Ecto.Type.type/0 .","ref":"Money.Ecto.Map.Type.html#type/0"},{"type":"module","title":"Money.Ecto.NumericCurrency.Type","doc":"Provides a type for Ecto to store a currency. The underlying data type is a integer. Migration create table ( :my_table ) do add :currency , :integer end Schema schema &quot;my_table&quot; do field :currency , Money.Ecto.NumericCurrency.Type end","ref":"Money.Ecto.NumericCurrency.Type.html"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.cast/1","doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"Money.Ecto.NumericCurrency.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.dump/1","doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"Money.Ecto.NumericCurrency.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.embed_as/1","doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Money.Ecto.NumericCurrency.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.equal?/2","doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Money.Ecto.NumericCurrency.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.load/1","doc":"Callback implementation for Ecto.Type.load/1 .","ref":"Money.Ecto.NumericCurrency.Type.html#load/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.type/0","doc":"Callback implementation for Ecto.Type.type/0 .","ref":"Money.Ecto.NumericCurrency.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Type","doc":"WARNING: This module is deprecated. Use Money.Ecto.Amount.Type module instead. Provides a type for Ecto usage. The underlying data type should be an integer. This type expects you to use a single currency. The currency must be defined in your configuration. config :money , default_currency : :GBP Migration Example create table ( :my_table ) do add :amount , :integer end Schema Example schema &quot;my_table&quot; do field :amount , Money.Ecto.Type end","ref":"Money.Ecto.Type.html"},{"type":"function","title":"Money.Ecto.Type.cast/1","doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"Money.Ecto.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Type.dump/1","doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"Money.Ecto.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Type.embed_as/1","doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Money.Ecto.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Type.equal?/2","doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Money.Ecto.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Type.load/1","doc":"Callback implementation for Ecto.Type.load/1 .","ref":"Money.Ecto.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Type.type/0","doc":"Callback implementation for Ecto.Type.type/0 .","ref":"Money.Ecto.Type.html#type/0"},{"type":"extras","title":"Money","doc":"Elixir library for working with Money safer, easier, and fun, is an interpretation of the Martin Fowler's Money pattern in functional programming. &quot;If I had a dime for every time I've seen someone use FLOAT to store currency, I'd have \\$999.997634&quot; -- Bill Karwin In short: You shouldn't represent monetary values by a float. Wherever you need to represent money, use Money .","ref":"readme.html"},{"type":"extras","title":"Money - Installation","doc":"Money comes with no required dependencies. Add the following to your mix.exs : def deps do [ { :money , &quot;~&gt; 1.12&quot; } ] end then run mix deps.get .","ref":"readme.html#installation"},{"type":"extras","title":"Money - Usage","doc":"five_eur = Money . new ( 500 , :EUR ) # %Money{amount: 500, currency: :EUR} ten_eur = Money . add ( five_eur , five_eur ) # %Money{amount: 10_00, currency: :EUR} hundred_eur = Money . multiply ( ten_eur , 10 ) # %Money{amount: 100_00, currency: :EUR} ninety_nine_eur = Money . subtract ( hundred_eur , 100 ) # %Money{amount: 99_00, currency: :EUR} shares = Money . divide ( ninety_nine_eur , 2 ) # [%Money{amount: 4950, currency: :EUR}, %Money{amount: 4950, currency: :EUR}] Money . equals? ( five_eur , Money . new ( 500 , :EUR ) ) # true Money . zero? ( five_eur ) ; # false Money . positive? ( five_eur ) ; # true Money.Currency . symbol ( :USD ) # $ Money.Currency . symbol ( Money . new ( 500 , :AFN ) ) # ؋ Money.Currency . name ( Money . new ( 500 , :AFN ) ) # Afghani Money . to_string ( Money . new ( 500 , :CNY ) ) # ¥ 5.00 Money . to_string ( Money . new ( 1_234_56 , :EUR ) , separator : &quot;.&quot; , delimiter : &quot;,&quot; , symbol : false ) &quot;1.234,56&quot; Money . to_string ( Money . new ( 1_234_56 , :USD ) , fractional_unit : false ) # &quot;$1,234&quot; Money . to_string ( Money . new ( 1_234_50 , :USD ) , strip_insignificant_zeros : true ) # &quot;$1,234.5&quot; Serialization to database with single currency Bring Money to your Ecto project. The underlying database type is integer Set a default currency in config.ex : config :money , default_currency : :USD Create migration with integer type: create table ( :jobs ) do add :amount , :integer end Create schema using the Money.Ecto.Amount.Type Ecto type (don't forget run mix ecto.migrate ): schema &quot;jobs&quot; do field :amount , Money.Ecto.Amount.Type end Save to the database: iex(1)&gt; Repo . insert % Job { amount : Money . new ( 100 , :USD ) } [ debug ] QUERY OK db = 90.7 ms queue = 0.1 ms INSERT INTO &quot;jobs&quot; ( &quot;amount&quot; , &quot;inserted_at&quot; , &quot;updated_at&quot; ) VALUES ( $ 1 , $ 2 , $ 3 ) RETURNING &quot;id&quot; [ 100 , { { 2019 , 2 , 12 } , { 7 , 29 , 8 , 589489 } } , { { 2019 , 2 , 12 } , { 7 , 29 , 8 , 593185 } } ] { :ok , % MoneyTest.Offers.Job { __meta__ : # Ecto.Schema.Metadata &lt; :loaded , &quot;jobs&quot; &gt; , amount : % Money { amount : 100 , currency : :USD } , id : 1 , inserted_at : ~N[2019-02-12 07:29:08.589489] , updated_at : ~N[2019-02-12 07:29:08.593185] } } Get from the database: iex(2)&gt; Repo . one ( Job , limit : 1 ) [ debug ] QUERY OK source = &quot;jobs&quot; db = 1.8 ms SELECT j0 . &quot;id&quot; , j0 . &quot;amount&quot; , j0 . &quot;inserted_at&quot; , j0 . &quot;updated_at&quot; FROM &quot;jobs&quot; AS j0 [ ] % MoneyTest.Offers.Job { __meta__ : # Ecto.Schema.Metadata &lt; :loaded , &quot;jobs&quot; &gt; , amount : % Money { amount : 100 , currency : :USD } , id : 1 , inserted_at : ~N[2019-02-12 07:29:08.589489] , updated_at : ~N[2019-02-12 07:29:08.593185] } Serialization to PostgreSQL with multiple currency Money.Ecto.Composite.Type Ecto type represents serialization of Money.t to PostgreSQL Composite Types with saving currency. Create migration with custom type: def up do execute &quot;&quot;&quot; CREATE TYPE public.money_with_currency AS (amount integer, currency varchar(3)) &quot;&quot;&quot; end def down do execute &quot;&quot;&quot; DROP TYPE public.money_with_currency &quot;&quot;&quot; end Then use created custom type( money_with_currency ) for money field: def change do alter table ( :jobs ) do add :price , :money_with_currency end end Create schema using the Money.Ecto.Composite.Type Ecto type (don't forget run mix ecto.migrate ): schema &quot;jobs&quot; do field :price , Money.Ecto.Composite.Type end Save to the database: iex(1)&gt; Repo . insert % Job { price : Money . new ( 100 , :JPY ) } [ debug ] QUERY OK db = 7.7 ms INSERT INTO &quot;jobs&quot; ( &quot;price&quot; , &quot;inserted_at&quot; , &quot;updated_at&quot; ) VALUES ( $ 1 , $ 2 , $ 3 ) RETURNING &quot;id&quot; [ { 100 , &quot;JPY&quot; } , { { 2019 , 2 , 12 } , { 8 , 7 , 44 , 729114 } } , { { 2019 , 2 , 12 } , { 8 , 7 , 44 , 729124 } } ] { :ok , % MoneyTest.Offers.Job { __meta__ : # Ecto.Schema.Metadata &lt; :loaded , &quot;jobs&quot; &gt; , id : 6 , inserted_at : ~N[2019-02-12 08:07:44.729114] , price : % Money { amount : 100 , currency : :JPY } , updated_at : ~N[2019-02-12 08:07:44.729124] } } Get from the database: iex(2)&gt; Repo . one ( Job , limit : 1 ) [ debug ] QUERY OK source = &quot;jobs&quot; db = 1.4 ms SELECT j0 . &quot;id&quot; , j0 . &quot;price&quot; , j0 . &quot;inserted_at&quot; , j0 . &quot;updated_at&quot; FROM &quot;jobs&quot; AS j0 [ ] % MoneyTest.Offers.Job { __meta__ : # Ecto.Schema.Metadata &lt; :loaded , &quot;jobs&quot; &gt; , id : 6 , inserted_at : ~N[2019-02-12 08:07:44.729114] , price : % Money { amount : 100 , currency : :JPY } , updated_at : ~N[2019-02-12 08:07:44.729124] } Serialization to database (JSON) with multiple currency Money.Ecto.Map.Type Ecto type represents serialization of Money.t to map(JSON) with saving currency. Create migration with map type: def change do alter table ( :jobs ) do add :price , :map end end Create schema using the Money.Ecto.Map.Type Ecto type (don't forget run mix ecto.migrate ): schema &quot;jobs&quot; do field :price , Money.Ecto.Map.Type end Save to the database: iex(1)&gt; Repo . insert % Job { price : Money . new ( 100 , :JPY ) } [ debug ] QUERY OK db = 4.6 ms INSERT INTO &quot;jobs&quot; ( &quot;price&quot; , &quot;inserted_at&quot; , &quot;updated_at&quot; ) VALUES ( $ 1 , $ 2 , $ 3 ) RETURNING &quot;id&quot; [ %{ &quot;amount&quot; =&gt; 100 , &quot;currency&quot; =&gt; &quot;JPY&quot; } , { { 2019 , 2 , 26 } , { 9 , 40 , 14 , 381721 } } , { { 2019 , 2 , 26 } , { 9 , 40 , 14 , 381730 } } ] { :ok , % MoneyTest.Offers.Job { __meta__ : # Ecto.Schema.Metadata &lt; :loaded , &quot;jobs&quot; &gt; , id : 9 , inserted_at : ~N[2019-02-26 09:40:14.381721] , price : % Money { amount : 100 , currency : :JPY } , updated_at : ~N[2019-02-26 09:40:14.381730] } } Get from the database: iex(8)&gt; Repo . one ( Job , limit : 1 ) [ debug ] QUERY OK source = &quot;jobs&quot; db = 2.0 ms SELECT j0 . &quot;id&quot; , j0 . &quot;price&quot; , j0 . &quot;inserted_at&quot; , j0 . &quot;updated_at&quot; FROM &quot;jobs&quot; AS j0 [ ] % MoneyTest.Offers.Job { __meta__ : # Ecto.Schema.Metadata &lt; :loaded , &quot;jobs&quot; &gt; , id : 10 , inserted_at : ~N[2019-02-26 09:40:45.205076] , price : % Money { amount : 100 , currency : :JPY } , updated_at : ~N[2019-02-26 09:40:45.205084] } Money.Sigils # Sigils for Money import Money.Sigils iex&gt; ~M[1000]USD % Money { amount : 1000 , currency : :USD } # If you have a default currency configured (e.g. to GBP), you can do iex&gt; ~M[1000] % Money { amount : 1000 , currency : :GBP } Money.Currency # Currency convenience methods import Money.Currency , only : [ usd : 1 , eur : 1 , afn : 1 ] iex&gt; usd ( 100_00 ) % Money { amount : 10000 , currency : :USD } iex&gt; eur ( 100_00 ) % Money { amount : 10000 , currency : :EUR } iex&gt; afn ( 100_00 ) % Money { amount : 10000 , currency : :AFN } Money.Currency . symbol ( :USD ) # $ Money.Currency . symbol ( afn ( 500 ) ) # ؋ Money.Currency . name ( afn ( 500 ) ) # Afghani Money.Currency . get ( :AFN ) # %{name: &quot;Afghani&quot;, symbol: &quot;؋&quot;} Phoenix.HTML.Safe Bring Money to your Phoenix project. If you are using Phoenix, you can include money objects directly into your output and they will be correctly escaped. &lt; b &gt; &lt; % = Money . new ( 12345 , 67 , :GBP ) % &gt; &lt; / b &gt;","ref":"readme.html#usage"},{"type":"extras","title":"Money - Configuration","doc":"You can set a default currency and default formatting preferences as follows: config :money , default_currency : :EUR , separator : &quot;.&quot; , delimiter : &quot;,&quot; , symbol : false , symbol_on_right : false , symbol_space : false , fractional_unit : true , strip_insignificant_zeros : false , code : false , minus_sign_first : true , strip_insignificant_fractional_unit : false Then you don’t have to specify the currency. iex&gt; amount = Money . new ( 1_234_50 ) % Money { amount : 123450 , currency : :EUR } iex&gt; to_string ( amount ) &quot;1.234,50&quot; Here is another example of formatting money: iex&gt; amount = Money . new ( 1_234_50 ) % Money { amount : 123450 , currency : :EUR } iex&gt; Money . to_string ( amount , symbol : true , symbol_on_right : true , symbol_space : true ) &quot;1.234,50 €&quot; Custom Currencies In some cases we can need to add not common currencies, like crypto currencies or others. In order to add your own currencies you have to add them in the config file following this format: config :money , custom_currencies : [ BTC : %{ name : &quot;Bitcoin&quot; , symbol : &quot;₿&quot; , exponent : 8 } , GCS : %{ name : &quot;Galactic Credit Standard&quot; , symbol : &quot;gcs&quot; , exponent : 0 } ]","ref":"readme.html#configuration"},{"type":"extras","title":"Money - Troubleshooting","doc":"Validating amount in Ecto changeset When using the Money.Ecto.Amount.Type type, it may seem that a simple value validation should work, for example: schema &quot;jobs&quot; do field :amount , Money.Ecto.Amount.Type end def changeset ( struct , params \\\\ %{ } ) do struct |&gt; cast ( params , [ :amount ] ) |&gt; validate_number ( :amount , [ greater_than : 0 ] ) end But this kind of validation will not work, since under the hood Money.Ecto.Amount.Type has the structure %Money{amount: ..., currency: ...} . To validate the data in this case, we recommend adding custom validation that matches your logic. Example: def changeset ( struct , params \\\\ %{ } ) do struct |&gt; cast ( params , [ :amount ] ) |&gt; validate_money ( :amount ) end defp validate_money ( changeset , field ) do validate_change ( changeset , field , fn _ , % Money { amount : amount } when amount &gt; 0 -&gt; [ ] _ , _ -&gt; [ amount : &quot;must be greater than 0&quot; ] end ) end Lack of precision when using Money.parse Sometimes you need to work with large numbers (for example, cryptocurrencies) and Float precision is not enough. In this case it is better to use Decimal package. Money already has support for Decimal and you just need to add it to your project dependencies.","ref":"readme.html#troubleshooting"},{"type":"extras","title":"Money - License","doc":"MIT License please see the LICENSE.md file.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"","ref":"changelog.html"},{"type":"extras","title":"Changelog - 1.12.3 – 2023-08-23","doc":"Fix map_type dump typespec (#204) Add SLE which is the new currency in Sierra Leone (#203) Bugfix: {Currency.Type.dump/1} missing ISO string support (#201)","ref":"changelog.html#1-12-3-2023-08-23"},{"type":"extras","title":"Changelog - 1.12.2 – 2023-01-19","doc":"Better error messages for Money.add and Monet.subtract (#191)","ref":"changelog.html#1-12-2-2023-01-19"},{"type":"extras","title":"Changelog - 1.12.1 – 2022-11-23","doc":"This release rolls back the breaking change in Money.parse . Support exponential notation feature will be added in the next major release. 🐛Bug Fixes Remove support exponential notation for Money.parse (#192) (#198)","ref":"changelog.html#1-12-1-2022-11-23"},{"type":"extras","title":"Changelog - 1.12.0 – 2022-11-18","doc":"🚀Enhancements Fix PEN currency symbol (#191) Migrate from travis ci to github actions (#193) Support exponential notation for Money.parse (#192) Add readme section about using Decimal (#194) Bump dependencies (#186)(#187)(#196)","ref":"changelog.html#1-12-0-2022-11-18"},{"type":"extras","title":"Changelog - 1.11.0 – 2022-08-15","doc":"🚀Enhancements Suggest using varchar instead of char on postgres (#178) Fix symbol_space with negative values (#180) Fix to_string to use the minus_sign_first option (#181) Adds support for strip_insignificant_fractional_unit option to to_string (#183) Fix Canadian and Singaporean Dollar symbols (#185)","ref":"changelog.html#1-11-0-2022-08-15"},{"type":"extras","title":"Changelog - 1.10.0 – 2022-04-10","doc":"🚀Enhancements Allow rounding Money values with Decimal (#177) Parse with Decimal if present (#176) Display minus sign before the currency symbol (fixes #154) (#173)","ref":"changelog.html#1-10-0-2022-04-10"},{"type":"extras","title":"Changelog - 1.9.0","doc":"🚀Enhancements Add Bolivar Soberano (#155) Improve Money.to_decimal to respect decimal places (#157) Add :code option for to_string rendering (#161) Allow Phoenix HTML 2.0 or 3.0 (#168) Support multiplying money by a decimal (#167) Use the rounding algorithm set in Decimal's context (#166) 🐛Bug Fixes Fix bug when using Money.to_decimal with amount 0 (#158)","ref":"changelog.html#1-9-0"},{"type":"extras","title":"Changelog - 1.8.0","doc":"🚀Enhancements Improves error message when Money.parse! fails Add Money.cmp/2 function Add decimal@v2.0.0 to optional list in mix.exs 🐛Bug Fixes Fix: avoic float rounding in Money.to_string Fix some type specs (did not include valid types) Fix Elixir 1.11.0 complain about variable usage Fix duplicate doc for Money.Currency.get/1","ref":"changelog.html#1-8-0"},{"type":"extras","title":"Changelog - 1.7.0","doc":"🚀Enhancements Add Elixir 1.9 and 1.10 to CI [#97] Support embedded schema for Money.Ecto.Amount.Type and Money.Ecto.Map.Type ecto types Support parsing %Decimal{} values in parse/3 and parse!/3 functions Support Money.to_decimal/1 to return the value as %Decimal{} Add currency ISO 4217 numbers support Money.equals? no longer raises when comparing different currencies Money.parse and Money.parse! now accept any number as argument","ref":"changelog.html#1-7-0"},{"type":"extras","title":"Changelog - 1.6.1","doc":"🐛Bug Fixes Revert Money.Ecto.Amount.Type casting to integer. This behavior leads to the fact that the structures after casting and loading from the database are different. Details #116","ref":"changelog.html#1-6-1"},{"type":"extras","title":"Changelog - 1.6.0","doc":"🚀Enhancements Strip insignificant zeros [#76] Check for the new using block for Ecto.Type in Ecto 3.2 [#112] Fix delimeter typo [#113] Money.Ecto.Amount.Type now casting to integer [#114]","ref":"changelog.html#1-6-0"},{"type":"extras","title":"Changelog - 1.5.1","doc":"🐛Bug Fixes Fix Money.Ecto.Type casting","ref":"changelog.html#1-5-1"},{"type":"extras","title":"Changelog - 1.5.0","doc":"🚀Enhancements Allow adding custom currencies [#108] Configure custom_currencies at runtime rather than compile time [#111] Add Philippine Piso sign [#104] Add support to cast from atom-keyed maps [#110] Fix readme typos in usage subtract and divide typos [#109] Add dializer and fix warnings 🐛Bug Fixes Fix typos with Money.Ecto.Map.Type docs [#105]","ref":"changelog.html#1-5-0"},{"type":"extras","title":"Changelog - 1.4.0","doc":"Now hex is supported by an open organization and we are happy for new contributors and maintainers. 🚀Enhancements Add support multiple currencies with map(JSON) type [#101] Add support multiple currencies with PostgreSQL composite type [#96] Add new Ecto Type for Currency [#87] Add credo and fix styles [#103] Formatting codebase [#102] Move repo to OSS organization and fix repo links after transfer [#99] Add Elixir 1.8.1 to CI [#97] ⛔️Deprecations Deprecate Money.Ecto.Type , use Money.Ecto.Amount.Type module instead 🐛Bug Fixes Fix dividing negative one [#95] Fix cast in Money.Ecto.Amount.Type from money with currency other than a default [#100]","ref":"changelog.html#1-4-0"},{"type":"extras","title":"Changelog - 1.3.2","doc":"Add Guaraní sign for PYG [#94] Add new Belarusian ruble [#92]","ref":"changelog.html#1-3-2"},{"type":"extras","title":"Changelog - 1.3.1","doc":"Support ecto 3.0 [#91]","ref":"changelog.html#1-3-1"},{"type":"extras","title":"Changelog - 1.3.0","doc":"Support elixir 1.6 and 1.7 versions [#90] Correct symbol for DKK [#86] Update supported elixir versions to 1.3 [#75] Fix deprecation warning for elixir 1.5 [#74] Add some more symbols for currencies [#71] Add some more symbols for currencies [#71] Fix official RUB symbol [#70] Adding a HexDoc link to the readme for faster linking to the docs [#68] Allow casting a Map of ecto's embeds_many [#66]","ref":"changelog.html#1-3-0"},{"type":"extras","title":"Changelog - 1.2.2","doc":"Fixing Mexican and Colombian pesos names [#63] Add support currency exponents [#60] Add ability to retrieve all currencies","ref":"changelog.html#1-2-2"},{"type":"extras","title":"Changelog - 1.2.1","doc":"Add Money.abs/1 Add Money.neg/1 Fix issues with Money.divide/2 and negative values [#57] Changes for clean compile on Elixir 1.4.1 Changed sigil functions to macros for compile time expansion [#59]","ref":"changelog.html#1-2-1"},{"type":"extras","title":"Changelog - 1.2.0","doc":"Add formatting option to hide fractional units [#47] Allow underscores in sigil [#48] 1.1.3 Fix parsing amounts without a leading digit [#46] 1.1.2 Bug fix: to_string with negative [#42] 1.1.1 No changes","ref":"changelog.html#1-2-0"},{"type":"extras","title":"Changelog - 1.1.0","doc":"Add formatting options [#36] Update parse to handle negative values [#39] Add support for Money.cast/1 for existing Money struct [#33] Add support for Money sigil ~M [#32] Add optional support for Phoenix.HTML.Safe [#29]","ref":"changelog.html#1-1-0"},{"type":"extras","title":"Changelog - 1.0.0","doc":"Initial release","ref":"changelog.html#1-0-0"},{"type":"extras","title":"Contribution Guidelines","doc":"","ref":"contributing.html"},{"type":"extras","title":"Contribution Guidelines - Steps","doc":"Fork the repo Make sure everything is working: mix test Create your feature branch ( git checkout -b my-new-feature ) Make your changes Test your changes Commit your changes ( git commit -am 'Add some feature' ) If needed please squash commits. Push to the branch ( git push origin my-new-feature ) Create a Pull Request","ref":"contributing.html#steps"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2016 Giulio De Donato Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}]